@@ -1,7 +1,5 @@
 import operator
 
-from .compat import PY2
-from .compat import PY3
 from .compat import string_types
 from .compat import with_metaclass
 from .utils import await_
@@ -94,8 +92,7 @@ class Proxy(with_metaclass(_ProxyMetaType)):
             return True
 
     @property
-    def __wrapped__(self, __getattr__=object.__getattribute__, __setattr__=object.__setattr__,
-                    __delattr__=object.__delattr__):
+    def __wrapped__(self, __getattr__=object.__getattribute__, __setattr__=object.__setattr__, __delattr__=object.__delattr__):
         try:
             return __getattr__(self, '__target__')
         except AttributeError:
@@ -145,23 +142,17 @@ class Proxy(with_metaclass(_ProxyMetaType)):
     def __str__(self):
         return str(self.__wrapped__)
 
-    if PY3:
-        def __bytes__(self):
-            return bytes(self.__wrapped__)
+    def __bytes__(self):
+        return bytes(self.__wrapped__)
 
     def __repr__(self, __getattr__=object.__getattribute__):
         try:
             target = __getattr__(self, '__target__')
         except AttributeError:
-            return '<{} at 0x{:x} with factory {!r}>'.format(
-                type(self).__name__, id(self),
-                self.__factory__
-            )
+            return '<{} at 0x{:x} with factory {!r}>'.format(type(self).__name__, id(self), self.__factory__)
         else:
             return '<{} at 0x{:x} wrapping {!r} at 0x{:x} with factory {!r}>'.format(
-                type(self).__name__, id(self),
-                target, id(target),
-                self.__factory__
+                type(self).__name__, id(self), target, id(target), self.__factory__
             )
 
     def __fspath__(self):
@@ -178,9 +169,8 @@ class Proxy(with_metaclass(_ProxyMetaType)):
     def __reversed__(self):
         return reversed(self.__wrapped__)
 
-    if PY3:
-        def __round__(self):
-            return round(self.__wrapped__)
+    def __round__(self):
+        return round(self.__wrapped__)
 
     def __lt__(self, other):
         return self.__wrapped__ < other
@@ -236,9 +226,6 @@ class Proxy(with_metaclass(_ProxyMetaType)):
     def __mul__(self, other):
         return self.__wrapped__ * other
 
-    def __div__(self, other):
-        return operator.div(self.__wrapped__, other)
-
     def __truediv__(self, other):
         return operator.truediv(self.__wrapped__, other)
 
@@ -378,10 +365,6 @@ class Proxy(with_metaclass(_ProxyMetaType)):
     def __int__(self):
         return int(self.__wrapped__)
 
-    if PY2:
-        def __long__(self):
-            return long(self.__wrapped__)  # noqa
-
     def __float__(self):
         return float(self.__wrapped__)
 
@@ -392,7 +375,10 @@ class Proxy(with_metaclass(_ProxyMetaType)):
         return hex(self.__wrapped__)
 
     def __index__(self):
-        return operator.index(self.__wrapped__)
+        if hasattr(self.__wrapped__, '__index__'):
+            return operator.index(self.__wrapped__)
+        else:
+            return int(self.__wrapped__)
 
     def __len__(self):
         return len(self.__wrapped__)
